==> google_cloud_binary_authorization-1.2.3-py2.py3-none-any.whl: google/cloud/binaryauthorization_v1beta1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .continuous_validation_logging import (
    ContinuousValidationEvent,
)
from .resources import (
    AdmissionRule,
    AdmissionWhitelistPattern,
    Attestor,
    AttestorPublicKey,
    PkixPublicKey,
    Policy,
    UserOwnedDrydockNote,
)
from .service import (
    CreateAttestorRequest,
    DeleteAttestorRequest,
    GetAttestorRequest,
    GetPolicyRequest,
    GetSystemPolicyRequest,
    ListAttestorsRequest,
    ListAttestorsResponse,
    UpdateAttestorRequest,
    UpdatePolicyRequest,
)

__all__ = (
    "ContinuousValidationEvent",
    "AdmissionRule",
    "AdmissionWhitelistPattern",
    "Attestor",
    "AttestorPublicKey",
    "PkixPublicKey",
    "Policy",
    "UserOwnedDrydockNote",
    "CreateAttestorRequest",
    "DeleteAttestorRequest",
    "GetAttestorRequest",
    "GetPolicyRequest",
    "GetSystemPolicyRequest",
    "ListAttestorsRequest",
    "ListAttestorsResponse",
    "UpdateAttestorRequest",
    "UpdatePolicyRequest",
)

==> google_cloud_binary_authorization-1.7.0-py2.py3-none-any.whl: google/cloud/binaryauthorization_v1beta1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .continuous_validation_logging import ContinuousValidationEvent
from .resources import (
    AdmissionRule,
    AdmissionWhitelistPattern,
    Attestor,
    AttestorPublicKey,
    PkixPublicKey,
    Policy,
    UserOwnedDrydockNote,
)
from .service import (
    CreateAttestorRequest,
    DeleteAttestorRequest,
    GetAttestorRequest,
    GetPolicyRequest,
    GetSystemPolicyRequest,
    ListAttestorsRequest,
    ListAttestorsResponse,
    UpdateAttestorRequest,
    UpdatePolicyRequest,
)

__all__ = (
    "ContinuousValidationEvent",
    "AdmissionRule",
    "AdmissionWhitelistPattern",
    "Attestor",
    "AttestorPublicKey",
    "PkixPublicKey",
    "Policy",
    "UserOwnedDrydockNote",
    "CreateAttestorRequest",
    "DeleteAttestorRequest",
    "GetAttestorRequest",
    "GetPolicyRequest",
    "GetSystemPolicyRequest",
    "ListAttestorsRequest",
    "ListAttestorsResponse",
    "UpdateAttestorRequest",
    "UpdatePolicyRequest",
)
